DataEditorConfig class

编辑可配置参数

Constructors

DataEditorConfig({Color bgColor = Colors.black, EdgeInsets cropRectPadding = const EdgeInsets.all(20.0), double cornerLength = 30, double cornerWidth = 4, Color cornerColor = Colors.blue, Size cornerHitTestSize = const Size(40, 40), Color lineColor = Colors.white, double lineWidth = 2, double lineHitTestWidth = 40, double dottedLength = 2, Color dottedColor = Colors.white, EditorMaskColorHandler? editorMaskColorHandler})

Properties

bgColor Color
final
cornerColor Color
final
cornerHitTestSize Size
final
cornerLength double
final
cornerWidth double
final
cropRectPadding EdgeInsets
final
dottedColor Color
final
dottedLength double
final
editorMaskColorHandler EditorMaskColorHandler?
final
hashCode int
The hash code for this object.
no setterinherited
lineColor Color
final
lineHitTestWidth double
final
lineWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited