ImageEditorPlane class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ImageEditorPlane
- Available extensions
Constructors
- ImageEditorPlane({Key? key, required ByteData imageData, required DataEditorConfig editorConfig, required ImageEditorController controller, required FunTailorResult onTailorResult})
-
const
Properties
- controller → ImageEditorController
-
final
- editorConfig → DataEditorConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageData → ByteData
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTailorResult → FunTailorResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{Key? key, int flex = 1}) → Expanded -
Available on Widget, provided by the WidgetExtension extension
Expanded 扩展 -
gestureDetector(
{Key? key, HitTestBehavior? behavior, void onTap()?, void onTapDown(TapDownDetails)?, void onTapCancel()?, void onVerticalDragDown(DragDownDetails)?, void onVerticalDragStart(DragStartDetails)?, void onVerticalDragUpdate(DragUpdateDetails)?, void onVerticalDragEnd(DragEndDetails)?, void onVerticalDragCancel()?, void onHorizontalDragDown(DragDownDetails)?, void onHorizontalDragStart(DragStartDetails)?, void onHorizontalDragUpdate(DragUpdateDetails)?, void onHorizontalDragEnd(DragEndDetails)?, void onHorizontalDragCancel()?, void onPanDown(DragDownDetails)?, void onPanStart(DragStartDetails)?, void onPanUpdate(DragUpdateDetails)?, void onPanEnd(DragEndDetails)?, void onPanCancel()?}) → GestureDetector -
Available on Widget, provided by the WidgetExtension extension
GestureDetector 扩展 -
gestureHorizontalWithData(
{Key? key, required DataDragDetailsGroup data, FunDragDown? onHorizontalDragDown, FunDragStart? onHorizontalDragStart, FunDragUpdate? onHorizontalDragUpdate, FunDragEnd? onHorizontalDragEnd, FunDragCancel? onHorizontalDragCancel}) → GestureDetector -
Available on Widget, provided by the WidgetExtension extension
GestureDetector 扩展 -
gesturePanWithData(
{Key? key, required DataDragDetailsGroup data, FunDragDown? onPanDown, FunDragStart? onPanStart, FunDragUpdate? onPanUpdate, FunDragEnd? onPanEnd, FunDragCancel? onPanCancel, void onTap()?, void onDoubleTap()?}) → GestureDetector -
Available on Widget, provided by the WidgetExtension extension
GestureDetector 扩展 -
gestureScaleWithData(
{Key? key, required DataScaleDetailsGroup data, FunScaleStart? onScaleStart, FunScaleUpdate? onScaleUpdate, FunScaleEnd? onScaleEnd}) → GestureDetector -
Available on Widget, provided by the WidgetExtension extension
GestureDetector 扩展 -
gestureVerticalWithData(
{Key? key, required DataDragDetailsGroup data, FunDragDown? onVerticalDragDown, FunDragStart? onVerticalDragStart, FunDragUpdate? onVerticalDragUpdate, FunDragEnd? onVerticalDragEnd, FunDragCancel? onVerticalDragCancel}) → GestureDetector -
Available on Widget, provided by the WidgetExtension extension
GestureDetector 扩展 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positioned(
{Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) → Positioned -
Available on Widget, provided by the WidgetExtension extension
Positioned 扩展 -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited