DataEditorConfig class

编辑可配置参数

Constructors

DataEditorConfig({Color bgColor = Colors.black, EdgeInsets cropRectPadding = const EdgeInsets.all(20.0), double cornerLength = 30, double cornerWidth = 4, Color cornerColor = Colors.blue, Size cornerHitTestSize = const Size(40, 40), Color lineColor = Colors.white, double lineWidth = 2, double lineHitTestWidth = 40, double dottedLength = 2, Color dottedColor = Colors.white, EditorMaskColorHandler? editorMaskColorHandler})

Properties

bgColor Color
编辑区域背景颜色
final
cornerColor Color
取景框边角颜色
final
cornerHitTestSize Size
取景框边角响应范围
final
cornerLength double
取景框边角长度
final
cornerWidth double
取景框边角宽度
final
cropRectPadding EdgeInsets
编辑区域widght的padding
final
dottedColor Color
取景框中九宫格虚线颜色
final
dottedLength double
取景框中九宫格虚线点单位长度
final
editorMaskColorHandler EditorMaskColorHandler?
配置取景器外部部分的颜色
final
hashCode int
The hash code for this object.
no setterinherited
lineColor Color
取景框四条边颜色
final
lineHitTestWidth double
取景框四条边响应面积宽度
final
lineWidth double
取景框四条边边宽
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited